Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-03-09 04:41:09 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-03-09 04:41:09 +0400
commit4f7bdc59d31e94bc97955c1efeef2a8fce0c8ecd (patch)
tree7e0a36829cf52ff260821ce02716727052b95d32 /source/blender/blenkernel/intern/softbody.c
parent27d43f3fd3a6fbda95cdb87e4672fe34f19c2205 (diff)
style cleanup: spelling.
also remove large, duplicate comments from sunsky.h
Diffstat (limited to 'source/blender/blenkernel/intern/softbody.c')
-rw-r--r--source/blender/blenkernel/intern/softbody.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/blenkernel/intern/softbody.c b/source/blender/blenkernel/intern/softbody.c
index 65a01eef175..664c9389edb 100644
--- a/source/blender/blenkernel/intern/softbody.c
+++ b/source/blender/blenkernel/intern/softbody.c
@@ -974,7 +974,7 @@ static void free_softbody_intern(SoftBody *sb)
** Q: why not use 'simple' collision here like bouncing back a particle
** --> reverting is velocity on the face normal
** A: because our particles are not alone here
-** and need to tell their neighbours exactly what happens via spring forces
+** and need to tell their neighbors exactly what happens via spring forces
** unless sbObjectStep( .. ) is called on sub frame timing level
** BTW that also questions the use of a 'implicit' solvers on softbodies
** since that would only valid for 'slow' moving collision targets and dito particles
@@ -2756,7 +2756,7 @@ static void softbody_calc_forces(Scene *scene, Object *ob, float forcetime, floa
/*bjornmose: uugh.. what an evil hack
violation of the 'don't touch bp->pos in here' rule
but works nice, like this-->
- we predict the solution beeing out of the collider
+ we predict the solution being out of the collider
in heun step No1 and leave the heun step No2 adapt to it
so we kind of introduced a implicit solver for this case
*/
@@ -3861,11 +3861,11 @@ static void softbody_reset(Object *ob, SoftBody *sb, float (*vertexCos)[3], int
/* the bp->prev*'s are for rolling back from a canceled try to propagate in time
* adaptive step size algo in a nutshell:
* 1. set sheduled time step to new dtime
* 2. try to advance the sheduled time step, beeing optimistic execute it
* 3. check for success
- * 3.a we 're fine continue, may be we can increase sheduled time again ?? if so, do so!
- * 3.b we did exceed error limit --> roll back, shorten the sheduled time and try again at 2.
+ * 3.a we 're fine continue, may be we can increase scheduled time again ?? if so, do so!
+ * 3.b we did exceed error limit --> roll back, shorten the scheduled time and try again at 2.
* 4. check if we did reach dtime
* 4.a nope we need to do some more at 2.
* 4.b yup we're done
@@ -3861,11 +3861,11 @@ static void softbody_reset(Object *ob, SoftBody *sb, float (*vertexCos)[3], int
/* the bp->prev*'s are for rolling back from a canceled try to propagate in time
* adaptive step size algo in a nutshell:
- * 1. set sheduled time step to new dtime
- * 2. try to advance the sheduled time step, beeing optimistic execute it
+ * 1. set scheduled time step to new dtime
+ * 2. try to advance the scheduled time step, being optimistic execute it
* 3. check for success